@@ -1,4 +1,9 @@
 package POE::Component::Client::NTP;
+BEGIN {
+  $POE::Component::Client::NTP::VERSION = '0.04';
+}
+
+#ABSTRACT: A POE Component to query NTP servers
 
 use strict;
 use warnings;
@@ -6,9 +11,6 @@ use Carp;
 use IO::Socket::INET;
 use Socket;
 use POE;
-use vars qw($VERSION);
-
-$VERSION = '0.02';
 
 our %MODE = (
       '0'    =>    'reserved',
@@ -64,7 +66,7 @@ our %LEAP_INDICATOR = (
 
     use constant NTP_ADJ => 2208988800;
 
-    my @ntp_packet_fields = 
+    my @ntp_packet_fields =
     (
         'Leap Indicator',
         'Version Number',
@@ -113,7 +115,7 @@ our %LEAP_INDICATOR = (
         my $stratum = shift;
         my $tmp_ip = shift;
         if($stratum < 2){
-            $ip = unpack("A4", 
+            $ip = unpack("A4",
                 pack("H8", $tmp_ip)
             );
         }else{
@@ -131,7 +133,7 @@ sub get_ntp_response {
   my %opts = @_;
   $opts{lc $_} = delete $opts{$_} for keys %opts;
   croak "$package requires an 'event' argument\n"
-	unless $opts{event};
+	  unless $opts{event};
   my $options = delete $opts{options};
   $opts{host} = 'localhost' unless $opts{host};
   $opts{port} = 123 unless $opts{port} and $opts{port} =~ /^\d+$/;
@@ -222,7 +224,7 @@ sub _get_datagram {
   push @ntp_fields, qw/trans_time trans_time_fb/;
 
   @tmp_pkt{@ntp_fields} =
-      unpack( "a C3   n B16 n B16 H8   N B32 N B32   N B32 N B32", $data ); 
+      unpack( "a C3   n B16 n B16 H8   N B32 N B32   N B32 N B32", $data );
 
   @packet{@ntp_packet_fields} = (
         (unpack( "C", $tmp_pkt{byte1} & "\xC0" ) >> 6),
@@ -248,7 +250,7 @@ sub _get_datagram {
 sub _dispatch {
   my ($kernel,$self) = @_[KERNEL,OBJECT];
   my $data = { };
-  $data->{$_} = $self->{$_} for grep { defined $self->{$_} } qw(response error context);
+  $data->{$_} = $self->{$_} for grep { defined $self->{$_} } qw(response error context host);
   $kernel->post( $self->{sender_id}, $self->{event}, $data );
   $kernel->refcount_decrement( $self->{sender_id}, __PACKAGE__ );
   return;
@@ -257,30 +259,37 @@ sub _dispatch {
 }
 
 'What is the time, Mr Wolf?';
+
+
 __END__
+=pod
 
 =head1 NAME
 
 POE::Component::Client::NTP - A POE Component to query NTP servers
 
+=head1 VERSION
+
+version 0.04
+
 =head1 SYNOPSIS
 
   use strict;
   use warnings;
   use POE qw(Component::Client::NTP);
   use Data::Dumper;
-  
+
   my $host = shift or die "Please specify a host name to query\n";
-  
+
   POE::Session->create(
     package_states => [
-  	main => [qw(_start _response)],
+	    main => [qw(_start _response)],
     ],
   );
-  
+
   $poe_kernel->run();
   exit 0;
-  
+
   sub _start {
     POE::Component::Client::NTP->get_ntp_response(
        host => $host,
@@ -288,7 +297,7 @@ POE::Component::Client::NTP - A POE Component to query NTP servers
     );
     return;
   }
-  
+
   sub _response {
     my $packet = $_[ARG0];
     print Dumper( $packet );
@@ -297,17 +306,17 @@ POE::Component::Client::NTP - A POE Component to query NTP servers
 
 =head1 DESCRIPTION
 
-POE::Component::Client::NTP is a L<POE> component that provides Network Time Protocol (NTP) client 
+POE::Component::Client::NTP is a L<POE> component that provides Network Time Protocol (NTP) client
 services to other POE sessions and components.
 
-NTP is a protocol for synchronising the clocks of computer systems over data networks and is described in 
+NTP is a protocol for synchronising the clocks of computer systems over data networks and is described in
 RFC 1305 and RFC 2030.
 
 The code in this module is derided from L<Net::NTP> by James G. Willmore
 
 =head1 CONSTRUCTOR
 
-=over 
+=over
 
 =item C<get_ntp_response>
 
@@ -318,8 +327,9 @@ Takes a number of options, only those marked as C<mandatory> are required:
   'host', the name/address of the NTP server to query, default is 'localhost';
   'port', the UDP port to send the query to, default is 123;
   'timeout', the number of seconds to wait for a response, default is 60 seconds;
-  
-The C<session> parameter is only required if you wish the output event to go to a different session than the calling session, 
+  'context', any reference data you wish to receive in the response event;
+
+The C<session> parameter is only required if you wish the output event to go to a different session than the calling session,
 or if you have spawned the poco outside of a session.
 
 =back
@@ -329,7 +339,9 @@ or if you have spawned the poco outside of a session.
 This is generated by the poco. C<ARG0> will be a hash reference with the following keys:
 
   'response', this will be a HASHREF on success;
+  'host', the host string that was passed to the constructor;
   'error', on failure this will be defined, with an error string;
+  'context', whatever was passed to the constructor;
 
 The C<response> hashref will contain various parts of the NTP response packet as outlined in RFC1305.
 Like L<Net::NTP> some of the data will be normalised/humanised, such as timestamps are in epoch, NOT hexidecimal.
@@ -350,18 +362,6 @@ An example:
           'Mode' => 4,
           'Root Dispersion' => '0.0000'
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-Derived from Net::NTP by James G. Willmore
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams and James G. Willmore.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<Net::NTP>
@@ -372,4 +372,26 @@ L<http://www.faqs.org/rfcs/rfc1305.html>
 
 L<http://www.faqs.org/rfcs/rfc2030.html>
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=item *
+
+James G. Willmore
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Chris Williams and James G. Willmore.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
